pub fn test_problem_spec(
_pack_name: &str,
inputs: Value,
) -> GateResult<ProblemSpec>Expand description
Helper to create a minimal problem spec for testing
pub fn test_problem_spec(
_pack_name: &str,
inputs: Value,
) -> GateResult<ProblemSpec>Helper to create a minimal problem spec for testing