pub fn test_problem_spec(_pack_name: &str, inputs: Value) -> Result<ProblemSpec>Expand description
Helper to create a minimal problem spec for testing
pub fn test_problem_spec(_pack_name: &str, inputs: Value) -> Result<ProblemSpec>Helper to create a minimal problem spec for testing